@@ -1,5 +1,5 @@
 fitWeights <- function(cell, thresh){
   n.body = length(which(cell$Loss <= thresh))
-  n.tail = length(which(cell$Loss > thresh))
-  return(1/(n.tail/n.body +1))
+  n.total = length(cell$Loss)
+  return(n.body/n.total)
 }
\ No newline at end of file
